@@ -341,7 +341,7 @@ class Checker(object):
             self.addBinding(node.lineno, Assignment(name, node))
 
         def runException():
-            for stmt in node.body:
+            for stmt in iter_child_nodes(node):
                 self.handleNode(stmt, node)
 
         self.deferFunction(runException)
@@ -366,7 +366,7 @@ class Checker(object):
                 existing = scope.get(value.name)
                 if (isinstance(existing, Importation)
                         and not existing.used
-                        and (not isinstance(value, Importation) \
+                        and (not isinstance(value, Importation)
                              or value.fullName == existing.fullName)
                         and reportRedef):
                     self.report(messages.RedefinedWhileUnused,
