@@ -5,6 +5,7 @@ Implementation of the command-line I{flake8} tool.
 import sys
 import os
 import os.path
+from subprocess import PIPE, Popen
 
 from flake8.util import skip_file
 from flake8 import pep8
@@ -46,7 +47,12 @@ def _get_python_files(paths):
 def main():
     options, args = pep8.process_options()
     complexity = options.max_complexity
+    builtins = set(options.builtins)
     warnings = 0
+
+    if builtins:
+        orig_builtins = set(pyflakes._MAGIC_GLOBALS)
+        pyflakes._MAGIC_GLOBALS = orig_builtins | builtins
     if args:
         for path in _get_python_files(args):
             warnings += check_file(path, complexity)
@@ -54,12 +60,14 @@ def main():
         stdin = sys.stdin.read()
         warnings += check_code(stdin, complexity)
 
+    if options.exit_zero:
+        raise SystemExit(0)
     raise SystemExit(warnings > 0)
 
 
 def _get_files(repo, **kwargs):
     seen = set()
-    for rev in xrange(repo[kwargs['node']], len(repo)):
+    for rev in range(repo[kwargs['node']], len(repo)):
         for file_ in repo[rev].files():
             file_ = os.path.join(repo.root, file_)
             if file_ in seen or not os.path.exists(file_):
@@ -91,7 +99,7 @@ class _PEP8Options(object):
     doctest = False
 
 
-def hg_hook(ui, repo, **kwargs):
+def _initpep8():
     # default pep8 setup
     pep8.options = _PEP8Options()
     pep8.options.physical_checks = pep8.find_checks('physical_line')
@@ -99,6 +107,36 @@ def hg_hook(ui, repo, **kwargs):
     pep8.options.counters = dict.fromkeys(pep8.BENCHMARK_KEYS, 0)
     pep8.options.messages = {}
     pep8.args = []
+
+
+def run(command):
+    p = Popen(command.split(), stdout=PIPE, stderr=PIPE)
+    p.wait()
+    return (p.returncode, [line.strip() for line in p.stdout.readlines()],
+            [line.strip() for line in p.stderr.readlines()])
+
+
+def git_hook(complexity=-1, strict=False):
+    _initpep8()
+    warnings = 0
+
+    _, files_modified, _ = run("git diff-index --cached --name-only HEAD")
+    for filename in files_modified:
+        ext = os.path.splitext(filename)[-1]
+        if ext != '.py':
+            continue
+        if not os.path.exists(filename):
+            continue
+        warnings += check_file(filename, complexity)
+
+    if strict:
+        return warnings
+
+    return 0
+
+
+def hg_hook(ui, repo, **kwargs):
+    _initpep8()
     complexity = ui.configint('flake8', 'complexity', default=-1)
     warnings = 0
 
